@@ -7,12 +7,12 @@ use warnings;
 use Path::Class;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Config::GitLike 1.11;
+use Config::GitLike 1.15;
 use utf8;
 
 extends 'Config::GitLike';
 
-our $VERSION = '0.9999';
+our $VERSION = 'v1.0.0'; # VERSION
 
 has '+confname' => ( default => 'sqitch.conf' );
 has '+encoding' => ( default => 'UTF-8' );
@@ -21,10 +21,8 @@ has '+encoding' => ( default => 'UTF-8' );
 my $SYSTEM_DIR = undef;
 
 sub user_dir {
-    require File::HomeDir;
-    my $hd = File::HomeDir->my_home or hurl config => __(
-        "Could not determine home directory"
-    );
+    my $hd = $^O eq 'MSWin32' && "$]" < '5.016' ? $ENV{HOME} || $ENV{USERPROFILE} : (glob('~'))[0];
+    hurl config => __("Could not determine home directory") if not $hd;
     return dir $hd, '.sqitch';
 }
 
@@ -56,10 +54,19 @@ sub local_file {
 
 sub dir_file { shift->local_file }
 
+# Section keys always have the top section lowercase, and subsections are
+# left as-is.
+sub _skey($) {
+    my $key = shift // return '';
+    my ($sec, $sub, $name) = Config::GitLike::_split_key($key);
+    return lc $key unless $sec;
+    return lc($sec) . '.' . join '.',   grep { defined } $sub, $name;
+}
+
 sub get_section {
     my ( $self, %p ) = @_;
     $self->load unless $self->is_loaded;
-    my $section = lc $p{section} // '';
+    my $section = _skey $p{section};
     my $data    = $self->data;
     return {
         map  {
@@ -75,6 +82,24 @@ sub initial_key {
     return ref $key ? $key->[0] : $key;
 }
 
+sub initialized {
+    my $self = shift;
+    $self->load unless $self->is_loaded;
+    return $self->{_initialized};
+}
+
+sub load_dirs {
+    my $self = shift;
+    local $self->{__loading_dirs} = 1;
+    $self->SUPER::load_dirs(@_);
+}
+
+sub load_file {
+    my $self = shift;
+    $self->{_initialized} ||= $self->{__loading_dirs};
+    $self->SUPER::load_file(@_);
+}
+
 1;
 
 =head1 Name
@@ -137,6 +162,14 @@ will be returned.
 
 An alias for C<local_file()> for use by the parent class.
 
+=head3 C<initialized>
+
+  say 'Project not initialized' unless $config->initialized;
+
+Returns true if the project configuration file was found, and false if it was
+not. Useful for detecting when a command has been run from a directory with no
+Sqitch configuration.
+
 =head3 C<get_section>
 
   my $core = $config->get_section(section => 'core');
@@ -157,17 +190,6 @@ Given the lowercase key from the loaded data, this method returns it in its
 original case. This is like C<original_key>, only in the case where there are
 multiple keys (for multivalue keys), only the first key is returned.
 
-=begin comment
-
-Hide <original_key>: It is defined in Config::GitLike 1.10, and only defined
-here for older versions.
-
-=head3 C<original_key>
-
-Only provided if not inherited from Config::GitLike.
-
-=end comment
-
 =head1 See Also
 
 =over
